pub struct ZstdThreads(pub(crate) u32);Expand description
The amount of threads to use when compressing using zstd.
The default (1) adheres to the one selected by the zstd executable.
If the custom amount of 0 is used, all available physical CPU cores are used.
Tuple Fields
0: u32Implementations
Sourceimpl ZstdThreads
impl ZstdThreads
Sourcepub fn new(threads: u32) -> Self
pub fn new(threads: u32) -> Self
Creates a new ZstdThreads from a u32.
Sourcepub fn all() -> Self
pub fn all() -> Self
Creates a new ZstdThreads which uses all physical CPU cores.
This is short for calling ZstdThreads::new with 0.